@@ -39,7 +39,7 @@ namespace K3b {
         
     public:
         explicit ThemeModel( ThemeManager* themeManager, QObject* parent = 0 );
-        ~ThemeModel();
+        ~ThemeModel() override;
         
         /**
          * Re-reads themes on disk and updates the model
@@ -49,11 +49,11 @@ namespace K3b {
         Theme* themeForIndex( const QModelIndex& index ) const;
         QModelIndex indexForTheme( Theme* theme, int column = ThemeColumn ) const;
         
-        virtual QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const;
-        virtual int columnCount( const QModelIndex& parent = QModelIndex() ) const;
-        virtual int rowCount( const QModelIndex& parent = QModelIndex() ) const;
-        virtual QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const;
-        virtual bool removeRows( int row, int count, const QModelIndex& parent = QModelIndex() );
+        QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const override;
+        int columnCount( const QModelIndex& parent = QModelIndex() ) const override;
+        int rowCount( const QModelIndex& parent = QModelIndex() ) const override;
+        QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const override;
+        bool removeRows( int row, int count, const QModelIndex& parent = QModelIndex() ) override;
         
     private:
         ThemeManager* m_themeManager;
